==> process-optaplanner-springboot-0.9.1-sources.jar: org/kie/kogito/examples/FlightsModel.java <==
package org.kie.kogito.examples;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogit-codegen", reference = "flights", name = "Flights", hidden = false)
public class FlightsModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("flight", this.flight);
        params.put("isSolving", this.isSolving);
        params.put("processId", this.processId);
        params.put("params", this.params);
        params.put("isPassengerListFinalized", this.isPassengerListFinalized);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.flight = (org.kie.kogito.examples.domain.Flight) params.get("flight");
        this.isSolving = (java.lang.Boolean) params.get("isSolving");
        this.processId = (java.lang.String) params.get("processId");
        this.params = (org.kie.kogito.examples.domain.FlightDTO) params.get("params");
        this.isPassengerListFinalized = (java.lang.Boolean) params.get("isPassengerListFinalized");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "flight")
    @javax.validation.Valid()
    private org.kie.kogito.examples.domain.Flight flight;

    public org.kie.kogito.examples.domain.Flight getFlight() {
        return flight;
    }

    public void setFlight(org.kie.kogito.examples.domain.Flight flight) {
        this.flight = flight;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "isSolving")
    @javax.validation.Valid()
    private java.lang.Boolean isSolving;

    public java.lang.Boolean getIsSolving() {
        return isSolving;
    }

    public void setIsSolving(java.lang.Boolean isSolving) {
        this.isSolving = isSolving;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "processId")
    @javax.validation.Valid()
    private java.lang.String processId;

    public java.lang.String getProcessId() {
        return processId;
    }

    public void setProcessId(java.lang.String processId) {
        this.processId = processId;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "params")
    @javax.validation.Valid()
    private org.kie.kogito.examples.domain.FlightDTO params;

    public org.kie.kogito.examples.domain.FlightDTO getParams() {
        return params;
    }

    public void setParams(org.kie.kogito.examples.domain.FlightDTO params) {
        this.params = params;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "isPassengerListFinalized")
    @javax.validation.Valid()
    private java.lang.Boolean isPassengerListFinalized;

    public java.lang.Boolean getIsPassengerListFinalized() {
        return isPassengerListFinalized;
    }

    public void setIsPassengerListFinalized(java.lang.Boolean isPassengerListFinalized) {
        this.isPassengerListFinalized = isPassengerListFinalized;
    }
}

==> process-optaplanner-springboot-0.10.0-sources.jar: org/kie/kogito/examples/FlightsModel.java <==
package org.kie.kogito.examples;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "flights", name = "Flights", hidden = false)
public class FlightsModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("flight", this.flight);
        params.put("isSolving", this.isSolving);
        params.put("processId", this.processId);
        params.put("params", this.params);
        params.put("isPassengerListFinalized", this.isPassengerListFinalized);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.flight = (org.kie.kogito.examples.domain.Flight) params.get("flight");
        this.isSolving = (java.lang.Boolean) params.get("isSolving");
        this.processId = (java.lang.String) params.get("processId");
        this.params = (org.kie.kogito.examples.domain.FlightDTO) params.get("params");
        this.isPassengerListFinalized = (java.lang.Boolean) params.get("isPassengerListFinalized");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "flight")
    @javax.validation.Valid()
    private org.kie.kogito.examples.domain.Flight flight;

    public org.kie.kogito.examples.domain.Flight getFlight() {
        return flight;
    }

    public void setFlight(org.kie.kogito.examples.domain.Flight flight) {
        this.flight = flight;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "isSolving")
    @javax.validation.Valid()
    private java.lang.Boolean isSolving;

    public java.lang.Boolean getIsSolving() {
        return isSolving;
    }

    public void setIsSolving(java.lang.Boolean isSolving) {
        this.isSolving = isSolving;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "processId")
    @javax.validation.Valid()
    private java.lang.String processId;

    public java.lang.String getProcessId() {
        return processId;
    }

    public void setProcessId(java.lang.String processId) {
        this.processId = processId;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "params")
    @javax.validation.Valid()
    private org.kie.kogito.examples.domain.FlightDTO params;

    public org.kie.kogito.examples.domain.FlightDTO getParams() {
        return params;
    }

    public void setParams(org.kie.kogito.examples.domain.FlightDTO params) {
        this.params = params;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "isPassengerListFinalized")
    @javax.validation.Valid()
    private java.lang.Boolean isPassengerListFinalized;

    public java.lang.Boolean getIsPassengerListFinalized() {
        return isPassengerListFinalized;
    }

    public void setIsPassengerListFinalized(java.lang.Boolean isPassengerListFinalized) {
        this.isPassengerListFinalized = isPassengerListFinalized;
    }
}
